CoreTriplesFactory
==================

.. currentmodule:: pykeen.triples

.. autoclass:: CoreTriplesFactory
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~CoreTriplesFactory.base_file_name
      ~CoreTriplesFactory.num_triples
      ~CoreTriplesFactory.triples_file_name

   .. rubric:: Methods Summary

   .. autosummary::

      ~CoreTriplesFactory.clone_and_exchange_triples
      ~CoreTriplesFactory.create
      ~CoreTriplesFactory.create_lcwa_instances
      ~CoreTriplesFactory.create_slcwa_instances
      ~CoreTriplesFactory.entities_to_ids
      ~CoreTriplesFactory.from_path_binary
      ~CoreTriplesFactory.get_inverse_relation_id
      ~CoreTriplesFactory.get_mask_for_relations
      ~CoreTriplesFactory.get_most_frequent_relations
      ~CoreTriplesFactory.iter_extra_repr
      ~CoreTriplesFactory.new_with_restriction
      ~CoreTriplesFactory.relations_to_ids
      ~CoreTriplesFactory.split
      ~CoreTriplesFactory.tensor_to_df
      ~CoreTriplesFactory.to_path_binary
      ~CoreTriplesFactory.with_labels

   .. rubric:: Attributes Documentation

   .. autoattribute:: base_file_name
   .. autoattribute:: num_triples
   .. autoattribute:: triples_file_name

   .. rubric:: Methods Documentation

   .. automethod:: clone_and_exchange_triples
   .. automethod:: create
   .. automethod:: create_lcwa_instances
   .. automethod:: create_slcwa_instances
   .. automethod:: entities_to_ids
   .. automethod:: from_path_binary
   .. automethod:: get_inverse_relation_id
   .. automethod:: get_mask_for_relations
   .. automethod:: get_most_frequent_relations
   .. automethod:: iter_extra_repr
   .. automethod:: new_with_restriction
   .. automethod:: relations_to_ids
   .. automethod:: split
   .. automethod:: tensor_to_df
   .. automethod:: to_path_binary
   .. automethod:: with_labels
